hctsaSimple predictors using the past trainLength values of the time series to predict its next value.
localsimple_taures(y, forecastMeth = c("mean", "lfit"),
trainLength = NULL)the input time series
the forecasting method, default to mean.
mean: local mean prediction using the past trainLength time-series values.
lfit: local linear prediction using the past trainLength time-series values.
the number of time-series values to use to forecast the next value.
Default to 1 when using method mean and 3 when using method lfit.
The first zero crossing of the autocorrelation function of the residuals